@@ -65,6 +65,8 @@ class TibberHome:
         self._hourly_consumption_data: HourlyData = HourlyData()
         self._hourly_production_data: HourlyData = HourlyData(production=True)
         self._last_rt_data_received: dt.datetime = dt.datetime.now()
+        self._rt_listener: None | asyncio.Task = None
+        self._rt_callback: Callable | None = None
 
     async def _fetch_data(self, hourly_data: HourlyData) -> None:
         """Update hourly consumption or production data asynchronously."""
@@ -410,6 +412,9 @@ class TibberHome:
         async def _start():
             """Subscribe to Tibber."""
             while True:
+                while not self._tibber_control.rt_subscription_running:
+                    _LOGGER.debug("Waiting for rt_connect")
+                    await asyncio.sleep(1)
                 try:
                     async for data in self._tibber_control.sub_manager.session.subscribe(
                         gql(LIVE_SUBSCRIBE % self.home_id)
@@ -427,13 +432,24 @@ class TibberHome:
                             data,
                         )
                 except Exception:  # pylint: disable=broad-except
-                    if self.rt_subscription_running:
-                        _LOGGER.exception("Error in rt_subscribe")
+                    _LOGGER.exception("Error in rt_subscribe")
                     await asyncio.sleep(10)
 
-        asyncio.create_task(_start())
+        self._rt_callback = callback
+        self._rt_listener = asyncio.create_task(_start())
         await self._tibber_control.rt_connect()
 
+    async def rt_resubscribe(self) -> None:
+        """Resubscribe to Tibber data."""
+        _LOGGER.debug("Resubscribe")
+        if self._rt_callback is None:
+            _LOGGER.warning("No callback set for rt_resubscribe")
+            return
+        if self._rt_listener is not None:
+            self._rt_listener.cancel()
+            self._rt_listener = None
+        await self.rt_subscribe(self._rt_callback)
+
     @property
     def rt_subscription_running(self) -> bool:
         """Is real time subscription running."""
